Package com.github.sonus21.rqueue.spring


package com.github.sonus21.rqueue.spring
  • Class
    Description
    This annotation can be used to auto configure Rqueue library by providing some sample configuration like by just providing RedisConnectionFactory.
    Checks whether MeterRegistry bean is present it or not.