Package com.github.sonus21.rqueue.spring
Annotation Interface EnableRqueue
@Target(TYPE)
@Retention(RUNTIME)
@Import(RqueueListenerConfig.class)
public @interface EnableRqueue
This annotation can be used to auto configure Rqueue library by providing some sample
configuration like by just providing
RedisConnectionFactory.
All other beans would be created automatically. Though other components of library can be
configured as well using
SimpleRqueueListenerContainerFactory. Even it can be
configured at very fine-grained level by creating all individual beans created in
RqueueListenerConfig